package CPAN::RPM;

use strict;
use warnings;

our $VERSION = "2.047";

1;

__END__

=head1 NAME

CPAN::RPM - A Perl module packager

=head1 DESCRIPTION

This module is required to let L<cpan2rpm> be found on CPAN. Do not remove.

=cut
